from area import Area
from screen import screen_size


__all__ = ['RectangularArea', 'CircularArea', 'FullscreenArea']


class RectangularArea(Area):
    """
    Rectangular area, has a position and a size.
    """
    def __init__(self, x, y, width, height):
        super(RectangularArea, self).__init__(x, y)
        self.set_size(width, height)

    def __str__(self):
        return '<%s at (%s, %s) size=(%s, %s)>' \
               % (self.__class__.__name__, self.x, self.y, self.width,
                  self.height)

    def set_size(self, width, height):
        self.width = width
        self.height = height
        self.update()

    def get_size(self):
        return self.width, self.height

    def contains(self, x, y):
        return self.x <= x <= self.x + self.width \
               and self.y <= y <= self.y + self.height

    def contains_event(self, event):
        return self.contains(*event.get_position())


class CircularArea(Area):
    """
    Circular area, has a position and a radius.
    """
    def __init__(self, x, y, radius):
        super(CircularArea, self).__init__(x, y)
        self.set_radius(radius)

    def __str__(self):
        return '<%s at (%s, %s) size=(%s, %s)>' \
               % (self.__class__.__name__, self.x, self.y, self.width,
                  self.height)

    def set_radius(self, radius):
        self.radius = radius
        self.update()

    def get_radius(self):
        return self.radius

    def contains_event(self, event):
        return event.distance_to(self) <= self.radius


class FullscreenArea(RectangularArea):
    """
    Area representation for the entire screen. This class provides an easy
    way to create a single rectangular area that catches all gestures.
    """
    def __init__(self):
        super(FullscreenArea, self).__init__(0, 0, *screen_size)

    def __str__(self):
        return '<FullscreenArea size=(%d, %d)>' % self.get_size()

    def contains(self, x, y):
        return True

    def contains_event(self, event):
        return True
